@@ -1,99 +1,86 @@
 package Archive::Any::Tar;
+{
+  $Archive::Any::Tar::VERSION = '0.0941';
+}
 
 use strict;
-use vars qw($VERSION @ISA);
-$VERSION = 0.02;
 
 require Archive::Any;
 @ISA = qw(Archive::Any);
 
-
 use Archive::Tar;
 use Cwd;
 
-
-
 sub new {
-    my($class, $file) = @_;
+    my ( $class, $file ) = @_;
 
     my $self = bless {}, $class;
 
-    $self->{handler} = Archive::Tar->new($file);
+    $self->{handler} = Archive::Tar->new( $file );
     return unless $self->{handler};
 
-    $self->{file}    = $file;
+    $self->{file} = $file;
 
     return $self;
 }
 
-
 sub files {
-    my($self) = shift;
+    my ( $self ) = shift;
 
     $self->{handler}->list_files;
 }
 
-
 sub extract {
-    my($self, $dir) = @_;
+    my ( $self, $dir ) = @_;
 
     my $orig_dir;
-    if( $dir ) {
+    if ( $dir ) {
         $orig_dir = getcwd;
         chdir $dir;
     }
 
     my $success = $self->{handler}->extract;
 
-    if( $dir) {
+    if ( $dir ) {
         chdir $orig_dir;
     }
 
     return $success;
 }
 
-
 sub type {
     return 'tar';
 }
 
-
-
 1;
 
+# ABSTRACT: Archive::Any wrapper around Archive::Tar
+
 __END__
 
 =pod
 
 =head1 NAME
 
-Archive::Any::Tar
+Archive::Any::Tar - Archive::Any wrapper around Archive::Tar
 
 =head1 VERSION
 
-version 0.0940
+version 0.0941
 
 =head1 SYNOPSIS
 
 B<DO NOT USE THIS MODULE DIRECTLY>
 
-Use Archive::Any instead.
+Use L<Archive::Any> instead.
 
 =head1 DESCRIPTION
 
-Wrapper around Archive::Tar for Archive::Any.
-
-=head1 NAME
-
-Archive::Any::Tar - Archive::Any wrapper around Archive::Tar
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>schwern@pobox.comE<gt>
+Wrapper around L<Archive::Tar> for L<Archive::Any>.
 
 =head1 SEE ALSO
 
-Archive::Any, Archive::Tar
+L<Archive::Any>, L<Archive::Tar>
 
 =head1 AUTHORS
 
