@@ -1,63 +1,59 @@
 package Archive::Any::Zip;
+{
+  $Archive::Any::Zip::VERSION = '0.0941';
+}
 
 use strict;
-use vars qw($VERSION @ISA);
-$VERSION = 0.03;
 
 require Archive::Any;
 @ISA = qw(Archive::Any);
 
-
 use Archive::Zip qw(:ERROR_CODES);
 use Cwd;
 
-
-
 sub new {
-    my($class, $file) = @_;
+    my ( $class, $file ) = @_;
 
     my $self = bless {}, $class;
 
-    Archive::Zip::setErrorHandler(sub {});
-    $self->{handler} = Archive::Zip->new($file);
+    Archive::Zip::setErrorHandler( sub { } );
+    $self->{handler} = Archive::Zip->new( $file );
     return unless $self->{handler};
 
-    $self->{file}    = $file;
+    $self->{file} = $file;
 
     return $self;
 }
 
-
 sub files {
-    my($self) = shift;
+    my ( $self ) = shift;
 
     $self->{handler}->memberNames;
 }
 
-
 sub extract {
-    my($self, $dir) = @_;
+    my ( $self, $dir ) = @_;
 
     my $orig_dir;
-    if( $dir ) {
+    if ( $dir ) {
         $orig_dir = getcwd;
         chdir $dir;
     }
 
     $self->{handler}->extractTree;
 
-    if( $dir) {
+    if ( $dir ) {
         chdir $orig_dir;
     }
 
     return 1;
 }
 
-
 sub type {
     return 'zip';
 }
 
+# ABSTRACT: Archive::Any wrapper around Archive::Zip
 
 
 1;
@@ -68,33 +64,21 @@ __END__
 
 =head1 NAME
 
-Archive::Any::Zip
+Archive::Any::Zip - Archive::Any wrapper around Archive::Zip
 
 =head1 VERSION
 
-version 0.0940
+version 0.0941
 
 =head1 SYNOPSIS
 
 B<DO NOT USE THIS MODULE DIRECTLY>
 
-Use Archive::Any instead.
+Use L<Archive::Any> instead.
 
 =head1 DESCRIPTION
 
-Wrapper around Archive::Zip for Archive::Any.
-
-=head1 NAME
-
-Archive::Any::Zip - Archive::Any wrapper around Archive::Zip
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>schwern@pobox.comE<gt>
-
-=head1 SEE ALSO
-
-Archive::Any, Archive::Zip
+Wrapper around L<Archive::Zip> for L<Archive::Any>.
 
 =head1 AUTHORS
 
